function varargout = op_networkverification(varargin)
% Outputs working GUIs. Makes .mat file necessary for running GUIs.
%
% op_networkverification
% [guihandlenames,working_database,interface_directories] = op_networt...
%
% INPUT(S):
%
%   [none] -- 
%
% OUTPUT(S):
%
%   guihandlenames -- (optional) handlenames to datasets, e.g., pushbutton39
%   working_database -- (optional) function names to working datasets,
%       e.g., get_goes, get_airs, get_[other]
%   interface_directories -- (optional) directory names corresponding to
%       directories within the Toolbox that are GUIs or have interfaces
%       associated with datasets (I know this is a little redundant here)
%
% If used without outputs, creates a file called "NetworkVerification.mat"
% (Assumes present working directory is /Common.)
%
% OPeNDAP Science Team
% Copyright 2007, 2008
% $Version 2.0.0$

%==========================================================================
% Christian Buckingham
% January 2008
%
% REVISION HISTORY:
% 2008/01/01 created, ceb
% 2008/02/07 edited, added OceanColor, ceb


%==========================================================================
guihandlenames = {'radiobutton1',...
               'radiobutton2',...
               'radiobutton3',...
               'radiobutton4',...
               'radiobutton5',...
               'radiobutton6',...
               'radiobutton7',... %'radiobutton8',...
               'pushbutton39'};
           
working_database = {'get_goes',...
                    'get_hycom',...
                    'get_oaflux',...
                    'get_pathfinder1km',...
                    'get_pathfinder4km',...
                    'get_seawinds',...
                    'get_airs',... %'get_modis',...
                    'get_oceancolor'};
                
% interface_directories = {'AIRS',...
%                          'GOES',...
%                          'HYCOM',... %'MODIS',...
%                          'OAFlux',...
%                          'Pathfinder1km',...
%                          'Pathfinder4km',...
%                          'SeaWinds',...
%                          'OceanColor'};

interface_directories = {'GOES',...
                         'HYCOM',...
                         'OAFlux',...
                         'Pathfinder1km',...
                         'Pathfinder4km',...
                         'SeaWinds',...
                         'AIRS',... %'MODIS',...
                         'OceanColor'};
                     
if nargout
    varargout{1} = guihandlenames;
    varargout{2} = working_database;
    varargout{3} = interface_directories;
else
    save NetworkVerification.mat
end

return %endoffunction