function dsi_oceancolor(varargin)
% updates the DataSetInventory structures
% without arguments for all the following DataSetBranches
if nargin < 1 
DSI_OceanColor_CZCS_9km_8day_hdf              
DSI_OceanColor_CZCS_9km_monthly_hdf            
DSI_OceanColor_MODIS_4km_3day_hdf               
DSI_OceanColor_MODIS_4km_8day_hdf
DSI_OceanColor_MODIS_9km_3day_hdf 
DSI_OceanColor_MODIS_9km_8day_hdf               
DSI_OceanColor_MergedMODISSeaWiFS_9km_1day_hdf  
DSI_OceanColor_MergedMODISSeaWiFS_9km_8day_hdf  
DSI_OceanColor_SeaWiFS_9km_8day_hdf             
elseif nargin > 1
disp('Incorrect number of arguments.'); return  
else
% with one argument for the specified DataSetBranch only     
eval(varargin{1}); 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_CZCS_9km_8day_hdf 
% create DataSetInventory of Ocean Color CZCS 

DSI.DataSetBranch='OceanColor_CZCS_9km_8day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/czcs/global/8_day/hdf/
%C19790011979008.L3m_8D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/czcs/global/8_day/hdf/
%C19790011979008.L3m_8D_L550_9.hdf?l3m_data[0:1:2159][0:1:4319]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
'L550'      ,'l3m_data';
};

LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;
DSI.FieldVariables.L550 =LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==255))=NaN;';
DSI.FormulaNaN.L550 ='f(find(f==255))=NaN;';

% Convert to physical units
DSI.FormulaCnv.Chlor='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';
DSI.FormulaCnv.L550 ='f=A.Global_Attributes.HDF_GLOBAL.Slope*f + A.Global_Attributes.HDF_GLOBAL.Intercept;';

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/czcs/global/8_day/hdf/';

% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.Chlor       =FNList(find(cellfun(@isempty,strfind(FNList,'8D_CHLO_9.hdf'))==0));
DSI.URLFILE.L550        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_L550_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
        
%C19790011979008.L3m_8D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In priciple, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=2160;NX=4320;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_CZCS_9km_monthly_hdf 
% create DataSetInventory of Ocean Color CZCS 

DSI.DataSetBranch='OceanColor_CZCS_9km_monthly_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/czcs/global/monthly/hdf/
%C19800011980031.L3m_MO_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==255))=NaN;';

% Convert to physical units
DSI.FormulaCnv.Chlor='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/czcs/global/monthly/hdf/';

% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.Chlor       =FNList(find(cellfun(@isempty,strfind(FNList,'MO_CHLO_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
        
%C19800011980031.L3m_MO_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In priciple, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=2160;NX=4320;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_MODIS_4km_3day_hdf 
% create DataSetInventory of Ocean Color MODIS 

DSI.DataSetBranch='OceanColor_MODIS_4km_3day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/3_day/hdf/
%A20070012007003.L3m_3D_CHLO_4.hdf?l3m_data[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/3_day/hdf/
%A20070012007003.L3m_3D_SST_4.hdf?l3m_data[0:1:4319][0:1:8639],l3m_qual[0:1:4319][0:1:8639]


% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
'SST'       ,'l3m_data';
'SST_qual'  ,'l3m_qual';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;
DSI.FieldVariables.SST=LatLon;
DSI.FieldVariables.SST_qual=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==255))=NaN;';
DSI.FormulaNaN.SST ='f(find(f==65535))=NaN;';
DSI.FormulaNaN.SST_qual ='f(find(f==255))=NaN;';

% Convert to physical units
DSI.FormulaCnv.Chlor='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';
DSI.FormulaCnv.SST ='f=A.Global_Attributes.HDF_GLOBAL.Slope*f + A.Global_Attributes.HDF_GLOBAL.Intercept;';
DSI.FormulaCnv.SST_qual ='';

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/modis/global/3_day/hdf/';

%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); % list of files with extention 'hdf'

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.Chlor       =FNList(find(cellfun(@isempty,strfind(FNList,'3D_CHLO_4.hdf'))==0));
DSI.URLFILE.SST         =FNList(find(cellfun(@isempty,strfind(FNList,'3D_SST_4.hdf' ))==0));
DSI.URLFILE.SST_qual    =FNList(find(cellfun(@isempty,strfind(FNList,'3D_SST_4.hdf' ))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%A20070012007003.L3m_3D_CHLO_4.hdf?l3m_data[0:1:4319][0:1:8639]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In principle, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time
% array T for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=4320;NX=8640;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_MODIS_4km_8day_hdf 
% create DataSetInventory of Ocean Color MODIS 

DSI.DataSetBranch='OceanColor_MODIS_4km_8day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_CHLO_4.hdf?l3m_data[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_A531_4.hdf?l3m_data[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_K490_4.hdf?l3m_data[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_L551_4.hdf?l3m_data[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_NSST_4.hdf?l3m_data[0:1:4319][0:1:8639],l3m_qual[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_SST_4.hdf?l3m_data[0:1:4319][0:1:8639]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_T869_4.hdf?l3m_data[0:1:4319][0:1:8639]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
'SST'       ,'l3m_data';
%'SST_qual'  ,''        ; % absent
'NSST_qual' ,'l3m_qual';
'NSST'      ,'l3m_data';
'A531'      ,'l3m_data';
'K490'      ,'l3m_data';
'L551'      ,'l3m_data';
'T869'      ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;
DSI.FieldVariables.SST=LatLon;
%DSI.FieldVariables.SST_qual=''; %LatLon; absent
DSI.FieldVariables.NSST=LatLon;
DSI.FieldVariables.NSST_qual=LatLon;
DSI.FieldVariables.A531=LatLon;
DSI.FieldVariables.K490=LatLon;
DSI.FieldVariables.L551=LatLon;
DSI.FieldVariables.T869=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==65535))=NaN;';
DSI.FormulaNaN.SST='f(find(f==255))=NaN;';
%DSI.FormulaNaN.SST_qual='';
DSI.FormulaNaN.NSST='f(find(f==65535))=NaN;';
DSI.FormulaNaN.NSST_qual='f(find(f==255))=NaN;';
DSI.FormulaNaN.A531='f(find(f==255))=NaN;';
DSI.FormulaNaN.K490='f(find(f==65535))=NaN;';
DSI.FormulaNaN.L551='f(find(f==255))=NaN;';
DSI.FormulaNaN.T869='f(find(f==255))=NaN;';

% Convert to physical units
CnvLog='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';
CnvLin='f=A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept;';
DSI.FormulaCnv.Chlor=CnvLog;
DSI.FormulaCnv.SST=CnvLin;
%DSI.FormulaCnv.SST_qual='';% absent
DSI.FormulaCnv.NSST=CnvLin;
DSI.FormulaCnv.NSST_qual='';
DSI.FormulaCnv.A531=CnvLin;
DSI.FormulaCnv.K490=CnvLog;
DSI.FormulaCnv.L551=CnvLin;
DSI.FormulaCnv.T869=CnvLin;

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/';

% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.Chlor       =FNList(find(cellfun(@isempty,strfind(FNList,'8D_CHLO_4.hdf'))==0));
DSI.URLFILE.SST         =FNList(find(cellfun(@isempty,strfind(FNList,'8D_SST_4.hdf' ))==0));
%DSI.URLFILE.SST_qual    =FNList(find(cellfun(@isempty,strfind(FNList,'8D_SST_4.hdf' ))==0));
DSI.URLFILE.NSST        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_NSST_4.hdf'))==0));
DSI.URLFILE.NSST_qual   =FNList(find(cellfun(@isempty,strfind(FNList,'8D_NSST_4.hdf'))==0));
DSI.URLFILE.A531        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_A531_4.hdf'))==0));
DSI.URLFILE.K490        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_K490_4.hdf'))==0));
DSI.URLFILE.L551        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_L551_4.hdf'))==0));
DSI.URLFILE.T869        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_T869_4.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%A20030012003008.L3m_8D_CHLO_4.hdf?l3m_data[0:1:4319][0:1:8639]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In principle, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT        
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=4320;NX=8640;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_MODIS_9km_3day_hdf 
% create DataSetInventory of Ocean Color MODIS 

DSI.DataSetBranch='OceanColor_MODIS_9km_3day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/3_day/hdf/
%A20060802006082.L3m_3D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/modis/global/3_day/hdf/';

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==255))=NaN;';

% Convert to physical units
DSI.FormulaCnv.Chlor='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';


%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); % list of files with extention 'hdf'

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.Chlor       =FNList(find(cellfun(@isempty,strfind(FNList,'3D_CHLO_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%A20070012007003.L3m_3D_CHLO_4.hdf?l3m_data[0:1:4319][0:1:8639]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In principle, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time
% array T for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=4320;NX=8640;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_MODIS_9km_8day_hdf 
% create DataSetInventory of Ocean Color MODIS

DSI.DataSetBranch='OceanColor_MODIS_9km_8day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_A531_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_K490_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_L551_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_NSST_9.hdf?l3m_data[0:1:2159][0:1:4319],l3m_qual[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_SST_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_T869_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/
%A20030012003008.L3m_8D_XS_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
'SST'       ,'l3m_data';
%'SST_qual'  ,'l3m_qual'; %absent
'NSST_qual' ,'l3m_qual';
'NSST'      ,'l3m_data';
'A531'      ,'l3m_data';
'K490'      ,'l3m_data';
'L551'      ,'l3m_data';
'T869'      ,'l3m_data';
'XSChlor'   ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;
DSI.FieldVariables.SST=LatLon;
%DSI.FieldVariables.SST_qual=''; %LatLon; absent
DSI.FieldVariables.NSST=LatLon;
DSI.FieldVariables.NSST_qual=LatLon;
DSI.FieldVariables.A531=LatLon;
DSI.FieldVariables.K490=LatLon;
DSI.FieldVariables.L551=LatLon;
DSI.FieldVariables.T869=LatLon;
DSI.FieldVariables.XSChlor=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==255))=NaN;';
DSI.FormulaNaN.SST='f(find(f==255))=NaN;';
%DSI.FormulaNaN.SST_qual=''; % absent
DSI.FormulaNaN.NSST='f(find(f==65535))=NaN;';
DSI.FormulaNaN.NSST_qual='f(find(f==255))=NaN;';
DSI.FormulaNaN.A531='f(find(f==255))=NaN;';
DSI.FormulaNaN.K490='f(find(f==255))=NaN;';
DSI.FormulaNaN.L551='f(find(f==255))=NaN;';
DSI.FormulaNaN.T869='f(find(f==255))=NaN;';
DSI.FormulaNaN.XSChlor='f(find(f==65535))=NaN;';

% Convert to physical units
CnvLog='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';
CnvLin='f=A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept;';
DSI.FormulaCnv.Chlor=CnvLog;
DSI.FormulaCnv.SST=CnvLin;
%DSI.FormulaCnv.SST_qual='';% absent
DSI.FormulaCnv.NSST=CnvLin;
DSI.FormulaCnv.NSST_qual='';
DSI.FormulaCnv.A531=CnvLin;
DSI.FormulaCnv.K490=CnvLog;
DSI.FormulaCnv.L551=CnvLin;
DSI.FormulaCnv.T869=CnvLin;
DSI.FormulaCnv.XSChlor=CnvLog;

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/modis/global/8_day/hdf/';

% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST will match NSST as well
DSI.URLFILE.Chlor       =FNList(find(cellfun(@isempty,strfind(FNList,'8D_CHLO_9.hdf'))==0));
DSI.URLFILE.SST         =FNList(find(cellfun(@isempty,strfind(FNList,'8D_SST_9.hdf' ))==0));
%DSI.URLFILE.SST_qual    =FNList(find(cellfun(@isempty,strfind(FNList,'8D_SST_9.hdf' ))==0));
DSI.URLFILE.NSST        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_NSST_9.hdf'))==0));
DSI.URLFILE.NSST_qual   =FNList(find(cellfun(@isempty,strfind(FNList,'8D_NSST_9.hdf'))==0));
DSI.URLFILE.A531        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_A531_9.hdf'))==0));
DSI.URLFILE.K490        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_K490_9.hdf'))==0));
DSI.URLFILE.L551        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_L551_9.hdf'))==0));
DSI.URLFILE.T869        =FNList(find(cellfun(@isempty,strfind(FNList,'8D_T869_9.hdf'))==0));
DSI.URLFILE.XSChlor     =FNList(find(cellfun(@isempty,strfind(FNList,'8D_XS_CHLO_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%A20030012003008.L3m_8D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]        
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In priciple, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT        
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=2160;NX=4320;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_SeaWiFS_9km_8day_hdf;
% create DataSetInventory of Ocean Color SeaWiFS

DSI.DataSetBranch='OceanColor_SeaWiFS_9km_8day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_A510_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_K490_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_L555_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_LND_NDVI_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_PAR_9.hdf?l3m_data[0:1:2159][0:1:4319]
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/
%S19980011998008.L3m_8D_T865_9.hdf?l3m_data[0:1:2159][0:1:4319]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'Chlor'     ,'l3m_data';
'A510'      ,'l3m_data';
'K490'      ,'l3m_data';
'L555'      ,'l3m_data';
'LND_NDVI'  ,'l3m_data';
'PAR'       ,'l3m_data';
'T865'      ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.Chlor=LatLon;
DSI.FieldVariables.A510=LatLon;
DSI.FieldVariables.K490=LatLon;
DSI.FieldVariables.L555=LatLon;
DSI.FieldVariables.LND_NDVI=LatLon;
DSI.FieldVariables.PAR=LatLon;
DSI.FieldVariables.T865=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.Chlor='f(find(f==65535))=NaN;';
DSI.FormulaNaN.A510='f(find(f==255))=NaN;';
DSI.FormulaNaN.K490='f(find(f==65535))=NaN;';
DSI.FormulaNaN.L555='f(find(f==255))=NaN;';
DSI.FormulaNaN.LND_NDVI='f(find(f==255))=NaN;';
DSI.FormulaNaN.PAR='f(find(f==65535))=NaN;';
DSI.FormulaNaN.T865='f(find(f==255))=NaN;';

% Convert to physical units
CnvLog='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';
CnvLin='f=A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept;';
DSI.FormulaCnv.Chlor=CnvLog;
DSI.FormulaCnv.A510=CnvLin;
DSI.FormulaCnv.K490=CnvLin;
DSI.FormulaCnv.L555=CnvLin;
DSI.FormulaCnv.LND_NDVI=CnvLin;
DSI.FormulaCnv.PAR=CnvLin;
DSI.FormulaCnv.T865=CnvLin;

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/seawifs/global/8_day/hdf/';
% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
DSI.URLFILE.Chlor     =FNList(find(cellfun(@isempty,strfind(FNList,'8D_CHLO_9.hdf'))==0));
DSI.URLFILE.A510      =FNList(find(cellfun(@isempty,strfind(FNList,'8D_A510_9.hdf'))==0));
DSI.URLFILE.K490      =FNList(find(cellfun(@isempty,strfind(FNList,'8D_K490_9.hdf'))==0));
DSI.URLFILE.L555      =FNList(find(cellfun(@isempty,strfind(FNList,'8D_L555_9.hdf'))==0));
DSI.URLFILE.LND_NDVI  =FNList(find(cellfun(@isempty,strfind(FNList,'8D_LND_NDVI_9.hdf'))==0));
DSI.URLFILE.PAR       =FNList(find(cellfun(@isempty,strfind(FNList,'8D_PAR_9.hdf'))==0));
DSI.URLFILE.T865      =FNList(find(cellfun(@isempty,strfind(FNList,'8D_T865_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%S19980011998008.L3m_8D_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In principle, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT        
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=2160;NX=4320;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_MergedMODISSeaWiFS_9km_1day_hdf 
% create DataSetInventory of Ocean Color Merged MODIS & SeaWiFS 

DSI.DataSetBranch='OceanColor_MergedMODISSeaWiFS_9km_1day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/merged_modis_seawifs/global/1_day/hdf/
%A2003001.L3m_DAY_XS_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'XSChlor'     ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.XSChlor=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.XSChlor='f(find(f==65535))=NaN;';

% Convert to physical units
DSI.FormulaCnv.XSChlor='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/merged_modis_seawifs/global/1_day/hdf/';

% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.XSChlor       =FNList(find(cellfun(@isempty,strfind(FNList,'DAY_XS_CHLO_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%A2003001.L3m_DAY_XS_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(2:8),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In priciple, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=2160;NX=4320;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OceanColor_MergedMODISSeaWiFS_9km_8day_hdf 
% create DataSetInventory of Ocean Color Merged MODIS & SeaWiFS 

DSI.DataSetBranch='OceanColor_MergedMODISSeaWiFS_9km_8day_hdf';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
%   constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
%   constraints URLCLAT URLCLON URLCDEPTH will be generated by program get

% Examples of files in the dataset
%http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/merged_modis_seawifs/global/8_day/hdf/
%A20030012003008.L3m_8D_XS_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]

% define list of fields or variables available in the dataset
% enter field names in rows; 
% columns reserved for defining alternative names and other properties associated with fields
% column 1 field name in opendap, column 2 variable name in dataset
DSI.Fields={
'XSChlor'     ,'l3m_data';
};
% variables each field depends on
LatLon={'latitude','longitude'};
DSI.FieldVariables.XSChlor=LatLon;

% Replace missing values with NaN
DSI.FormulaNaN.XSChlor='f(find(f==65535))=NaN;';

% Convert to physical units
DSI.FormulaCnv.XSChlor='f=A.Global_Attributes.HDF_GLOBAL.Base.^(A.Global_Attributes.HDF_GLOBAL.Slope*f+A.Global_Attributes.HDF_GLOBAL.Intercept);';

% url location of the dataset files
DSI.URLSITE='http://www.marine.csiro.au';
DSI.URLPATH='/dods/nph-dods/dods-data/ocean_colour/merged_modis_seawifs/global/8_day/hdf/';

% obtain list of files with extention 'hdf'
%FNList=htmldirlist(URL,EXT)
FNList=htmldirlist([DSI.URLSITE DSI.URLPATH],'hdf'); 

% exctract the list of files corresponding to each field or variable
% note that string 8D_ is required otherwise SST_4 will match NSST_4 as well
DSI.URLFILE.XSChlor       =FNList(find(cellfun(@isempty,strfind(FNList,'8D_XS_CHLO_9.hdf'))==0));

DSI.URLCTIME=''; % empty not used in this dataset
DSI.URLCDEPTH=''; % empty not used in this dataset

% browse through list of fields and obtain array of available times for each field
for kf=1:length(DSI.Fields(:,1)) 
FIELD=DSI.Fields{kf,1};    
eval(['FNList=DSI.URLFILE.' FIELD ';'])
CVAR=DSI.Fields{kf,2};
eval(['DSI.URLCVAR.' FIELD '=''' CVAR ''';']) 

% define empty arrays
eval(['DSI.Time.'  FIELD '=[];'])    % double array: center of time interval
eval(['DSI.TimeA.' FIELD '=[];'])    % double array: beginning of time interval
eval(['DSI.TimeB.' FIELD '=[];'])    % double array: end of time interval
    for kt=1:length(FNList)
%A20030012003008.L3m_8D_XS_CHLO_9.hdf?l3m_data[0:1:2159][0:1:4319]
FN=FNList{kt};
tA=datenum(FN(2:8),'yyyyddd');
tB=datenum(FN(9:15),'yyyyddd')+1;
t=(tA+tB)*0.5;
eval(['DSI.TimeA.' FIELD '(end+1)=tA;'])
eval(['DSI.TimeB.' FIELD '(end+1)=tB;'])
eval(['DSI.Time.'  FIELD '(end+1)=t;' ])
    end %kt
end %kf

% In priciple, for each time there should be files corresponding to every field. 
% But some may be missing. Merge time arrays in order to find common time array T 
% for which at least one field is available.
% P contains pointers to elements in the original lists.
% Q containt a pointer to the array that contributed the value 
%[T,P,Q]=mergearrays(DSI.Time.Chlor,DSI.Time.SST,DSI.Time.SST_qual,...)
T=struct2cell(DSI.Time);
[T,P,Q]=mergearrays(T{:});

NT=length(T);
NV=length(DSI.Fields(:,1));
for kv=1:NV
FIELD=DSI.Fields{kv,1};
eval(['F=DSI.URLFILE.' FIELD ';'])
eval(['DSI.URLFILE.' FIELD '=cell(NT,1);'])
    for k=1:NT
        if P(k,kv)>0
eval(['DSI.URLFILE.' FIELD '{k}=F{P(k,kv)};'])
        end
    end
end
DSI.Time=T;
TA=struct2cell(DSI.TimeA);
TB=struct2cell(DSI.TimeB);
DSI.TimeA=zeros(NT,1);
DSI.TimeB=zeros(NT,1);
for k=1:NT
DSI.TimeA(k)=TA{Q(k)}(P(k,Q(k)));
DSI.TimeB(k)=TB{Q(k)}(P(k,Q(k)));        
end

NY=2160;NX=4320;
DSI.Latitude =  90-((1:1:NY)-0.5)'/NY*180;
DSI.Longitude=-180+((1:1:NX)-0.5)'/NX*360;

DSI.Range.Time1=min(DSI.TimeA);
DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%S4='';%['time is MATLAB datenum.'];
DSI.Readme=[S1 '/' S2 '/' S3];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oceancolor.mat','file') 
eval(['save dsi_oceancolor.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oceancolor.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function S=htmldirlist(URL,EXT)
% gets the list of files with extension EXT in the directory pointed to by URL

%S=urlread('http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/czcs/global/8_day/netcdf/')
%URL='http://www.marine.csiro.au/dods/nph-dods/dods-data/ocean_colour/czcs/global/8_day/netcdf/'
%EXT='nc'
U=urlread(URL);
S=U;

%<img src="/icons/unknown.gif" alt="[   ]"> 
%<A HREF=czcs_1980_8D_chlor.nc.html>czcs_1980_8D_chlor.nc</a>
%29-May-2007 07:45  409M  
%regexp(S,'html','match')
% match filenames between the leading and trailing strings
SS=regexp(S,[EXT '\.html>.*?\.' EXT '</a>'],'match')';
%[k1,k2]=regexp(S,[EXT '\.html>.*?\.' EXT '</a>'],'start','end');

%cut the the leading and trailing strings 
L1=length([EXT '.html>']);
L2=length(['</a>']);
S=SS;
for k=1:length(S)
S1=SS{k};    
S{k}=S1(L1+1:end-L2);
end
S(:);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [a,p,q]=mergearrays(varargin)
% [a,p,q]=mergearrays(a1,a2,...,aM) 
%           merges two or more (M) integer arrays 
% input:    a1,a2,...,aM arrays to be merged. Each array aj may have different 
%               lengths.
% output:   a(i) merged array containing all possible values in a1,a2,...,aM
%               (without repetition). 
%               The pointers p(i,j) refer to the index in 
%               the original arrays a1,a2,...aM. The pointer is set to zero p(i,j)=0 
%               if the value is not available in the original array aj.
%               The pointer q(i) inicates which array contributed value first
%
% Example:
% a1    =[010;020;030;050;060;070;080;090;100];
% a2    =[030;040;060;070;080;090;100;120];
% a     =[010;020;030;040;050;060;070;080;090;100;120];
% p(:,1)=[  1;  2;  3;  0;  4;  5;  6;  7;  8;  9;  0];
% p(:,2)=[  0;  0;  1;  2;  0;  3;  4;  5;  6;  7;  8];
% q(:)  =[  1;  1;  1;  2;  1;  1;  1;  1;  1;  1;  2];
%
% if M=1 then a=a1 p=[1:length(a1)]'

A=varargin;
M=length(A); % number of arrays to merge 
NA=cellfun(@length,A); % length of each array
N=max(NA); % the length of the longest array 
Na=sum(NA); % the maximum possible length of array a
a=zeros(Na,1)+inf; % allocate memory, initialize values to inf
p=zeros(Na,M);     % allocate memory, initialize pointers to 0
q=zeros(Na,1);     % allocate memory, initialize pointers to 0
% convert the input cell array into matrix; initialize it to inf (because
% we use min) make one extra row 
B=zeros(N+1,M)+inf;
for k=1:M
B(1:NA(k),k)=A{k};
end
kk=ones(1,M); % pointers to the current element in the original array
ka=0;         % pointer to the element of the output array 

L=1;
while L % at least one of kk points to a valid value in aj 
    x=[];
    for k=1:M
        x=[x B(kk(k),k)];
    end    
    [v,i]=min(x);
% starting from the beginning of the arrays find the minimal value    
   %[v,i]=min([B(kk(1),1) B(kk(2),2) B(kk(3),3)]);  
    if ka==0 | v>a(ka)
% if there is nothing in a yet or the minimal value is larger than the last
% in a
        ka=ka+1;
        a(ka)=v; % then add the new value to a
        p(ka,i)=kk(i); % add the pointer to p
        q(ka)=i;       % add the pointer to q
        kk(i)=kk(i)+1; % and increment the pointer kk
    else 
 % otherwise just add the pointer. The same value is present in more than one array 
        p(ka,i)=kk(i); 
        kk(i)=kk(i)+1;
    end
    L=0; 
    for k=1:M
    L=L | kk(k)<=NA(k); % at least one of kk points to a valid value in aj 
    end
end %while
a=a(1:ka); % keep only the valid values, cut out extra memory 
p=p(1:ka,:);
q=q(1:ka,:);

