function varargout = gui_pathfinder4km(varargin)
% Boots-up Pathfinder4km GUI, interacts with user via interface.
% gui_pathfinder4km M-file for gui_pathfinder4km.fig
%
% INPUT(S):
%
%   [none]
%
% OUTPUT(S)
%
%   h -- (optional) GUI handle
%
% Meri Sheremet
% June 2007

warning('off','MATLAB:dispatcher:InexactMatch');
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_pathfinder4km_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_pathfinder4km_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
warning('on','MATLAB:dispatcher:InexactMatch');

% --- Executes just before gui_pathfinder4km is made visible.
function gui_pathfinder4km_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui_pathfinder4km (see VARARGIN)

% Define handles "openfigure" field.
if ~isfield(handles,'openfigure')
    handles.openfigure = 0; %set equal to zero on the first time.
end

% Set interface name.
txt = ['NASA/REASoN Ocean Data Portal - '];
tmp1 = ['Pathfinder4km GUI'];
tmp2 = strrep(op_version('mfile',strrep(mfilename,'gui','get')),'Version ','');
txt = [txt,tmp1,' (Ver ',tmp2,')'];
set(hObject,'Name',txt);

% Place logos on the GUI with links
% determine screen resolution and size of character in pixels
Units0=get(0,'Units'); % save initial settings
set(0,'Units','characters');
SSC=get(0,'ScreenSize'); % screen size in characters
set(0,'Units','pixels');
SSP=get(0,'ScreenSize'); % screen size in pixels
set(0,'Units',Units0); % restore to original units
ppcx=SSP(3)/SSC(3); % pixels per character along x
ppcy=SSP(4)/SSC(4); % pixels per character along y

[img,MAP]=imread('logo_nasa1.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton9,'CData',img)
pos = get(handles.pushbutton9,'position'); %units will be in characters
set(handles.pushbutton9,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_opendap.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton7,'CData',img)
pos = get(handles.pushbutton7,'position'); %units will be in characters
set(handles.pushbutton7,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_noaa_nodc.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;
CY=(NY+12)/ppcy;
set(handles.pushbutton5,'CData',img)
pos = get(handles.pushbutton5,'position'); %units will be in characters
set(handles.pushbutton5,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_podaac.jpg');
[NY,NX,N3]=size(img);
CX=(NX+4)/ppcx;
CY=(NY+4)/ppcy;
set(handles.pushbutton8,'CData',img)
pos = get(handles.pushbutton8,'position'); %units will be in characters
set(handles.pushbutton8,'position',[pos(1),pos(2),CX,CY]);

txt=['Help'];
op_tooltipwrap(handles.pushbutton10,txt,50);

[img,MAP]=imread('logo_questionmark.jpg');
% [NY,NX,N3]=size(img);
% CX=(NX+8)/ppcx;
% CY=(NY+12)/ppcy;
% set(handles.pushbutton10,'CData',img)
% pos = get(handles.pushbutton10,'position'); %units will be in characters
% set(handles.pushbutton10,'position',[pos(1),pos(2),CX,CY]);
[N1,N2,N3]=size(img);
set(handles.pushbutton10,'string','')
set(handles.pushbutton10,'CData',img)
set(handles.pushbutton10,'Units','pixels')
pos = get(handles.pushbutton10,'position');
set(handles.pushbutton10,'position',[pos(1) pos(2) N1 N2])

if get(handles.radiobutton1,'Value')==0 & get(handles.radiobutton2,'Value')==0
set(handles.radiobutton1,'Value',1)
end

if get(handles.radiobutton7,'Value')==0 & get(handles.radiobutton8,'Value')==0
set(handles.radiobutton7,'Value',1)
end

% Make 'Load Last Request' button inactive when file gui_pathfinder4km_request.mat is
% absent
pname = strrep(mfilename('fullpath'),mfilename,'');
fname = [mfilename,'_request','.mat'];
%'gui_pathfinder4km_request.mat';
if ~exist([pname,fname],'file') 
    set (handles.pushbutton6,'Enable','Off')
end

% Climatology vs Time Series
ClimTimeSeriesCheck(hObject, eventdata, handles)
QualMaskOnOff(hObject, eventdata, handles)
SaveFilesOnOff(hObject, eventdata, handles)

InterimDataCheck(hObject, eventdata, handles)

set(handles.pushbutton4,'String','Get Data','BackgroundColor',[0 1. 0.25])

% Update handles "openfigure" field.
handles.openfigure = 1;

% Choose default command line output for gui_pathfinder4km
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui_pathfinder4km wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = gui_pathfinder4km_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

function radiobutton1_Callback(hObject, eventdata, handles)
if get(handles.radiobutton1,'Value') == 0
    set(handles.radiobutton2,'Value',1)
else
    set(handles.radiobutton2,'Value',0)
end
ClimTimeSeriesCheck(hObject, eventdata, handles)
InterimDataCheck(hObject, eventdata, handles)

function radiobutton2_Callback(hObject, eventdata, handles)
if get(handles.radiobutton2,'Value') == 0
    set(handles.radiobutton1,'Value',1)
else
    set(handles.radiobutton1,'Value',0)
end
ClimTimeSeriesCheck(hObject, eventdata, handles)
InterimDataCheck(hObject, eventdata, handles)

function checkbox1_Callback(hObject, eventdata, handles)
function checkbox2_Callback(hObject, eventdata, handles)
QualMaskOnOff(hObject, eventdata, handles)
function checkbox3_Callback(hObject, eventdata, handles)
function checkbox4_Callback(hObject, eventdata, handles)
function checkbox5_Callback(hObject, eventdata, handles)
function checkbox6_Callback(hObject, eventdata, handles)
QualMaskOnOff(hObject, eventdata, handles)
function checkbox7_Callback(hObject, eventdata, handles)
  if get(handles.checkbox7,'Value') == 1 % if requesting anomaly,
     set(handles.checkbox5,'Value',1)    % request sst as well
  end
function checkbox8_Callback(hObject, eventdata, handles)
QualMaskOnOff(hObject, eventdata, handles)
function checkbox9_Callback(hObject, eventdata, handles)
function checkbox10_Callback(hObject, eventdata, handles)
function checkbox11_Callback(hObject, eventdata, handles)
function checkbox12_Callback(hObject, eventdata, handles)
function checkbox13_Callback(hObject, eventdata, handles)
function checkbox14_Callback(hObject, eventdata, handles)

function edit1_CreateFcn(hObject, eventdata, handles)
function edit1_Callback(hObject, eventdata, handles)
function edit2_CreateFcn(hObject, eventdata, handles)
function edit2_Callback(hObject, eventdata, handles)
function edit3_CreateFcn(hObject, eventdata, handles)
function edit3_Callback(hObject, eventdata, handles)
function edit4_CreateFcn(hObject, eventdata, handles)
function edit4_Callback(hObject, eventdata, handles)
InterimDataCheck(hObject, eventdata, handles)
function edit5_CreateFcn(hObject, eventdata, handles)
function edit5_Callback(hObject, eventdata, handles)
function edit6_CreateFcn(hObject, eventdata, handles)
function edit6_Callback(hObject, eventdata, handles)
function edit7_CreateFcn(hObject, eventdata, handles)
function edit7_Callback(hObject, eventdata, handles)
function edit8_CreateFcn(hObject, eventdata, handles)
function edit8_Callback(hObject, eventdata, handles)
function edit9_CreateFcn(hObject, eventdata, handles)
function edit9_Callback(hObject, eventdata, handles)
function edit10_CreateFcn(hObject, eventdata, handles)
function edit10_Callback(hObject, eventdata, handles)
function edit11_CreateFcn(hObject, eventdata, handles)
function edit11_Callback(hObject, eventdata, handles)
function edit12_CreateFcn(hObject, eventdata, handles)
function edit12_Callback(hObject, eventdata, handles)
function edit13_CreateFcn(hObject, eventdata, handles)
function edit13_Callback(hObject, eventdata, handles)
function edit14_CreateFcn(hObject, eventdata, handles)
function edit14_Callback(hObject, eventdata, handles)
function edit15_Callback(hObject, eventdata, handles)
function edit15_CreateFcn(hObject, eventdata, handles)

function popupmenu1_CreateFcn(hObject, eventdata, handles)
function popupmenu1_Callback(hObject, eventdata, handles)
function popupmenu2_CreateFcn(hObject, eventdata, handles)
function popupmenu2_Callback(hObject, eventdata, handles)
ClimTimeSeriesCheck(hObject, eventdata, handles)
function popupmenu3_CreateFcn(hObject, eventdata, handles)
function popupmenu3_Callback(hObject, eventdata, handles)
ClimTimeSeriesCheck(hObject, eventdata, handles)

function radiobutton3_Callback(hObject, eventdata, handles)
Pass{1}='y';
InterimDataCheck(hObject, eventdata, handles)
function radiobutton4_Callback(hObject, eventdata, handles)
Pass{2}='y';
InterimDataCheck(hObject, eventdata, handles)
function radiobutton5_Callback(hObject, eventdata, handles)
Pass{3}='y';
InterimDataCheck(hObject, eventdata, handles)
function radiobutton6_Callback(hObject, eventdata, handles)
Pass{4}='y';
InterimDataCheck(hObject, eventdata, handles)

function pushbutton2_Callback(hObject, eventdata, handles)
if strcmp(get(handles.radiobutton3,'Visible'),'on'); set(handles.radiobutton3,'Value',1); Pass{1}='y'; end
if strcmp(get(handles.radiobutton4,'Visible'),'on'); set(handles.radiobutton4,'Value',1); Pass{2}='y'; end
if strcmp(get(handles.radiobutton5,'Visible'),'on'); set(handles.radiobutton5,'Value',1); Pass{3}='y'; end
if strcmp(get(handles.radiobutton6,'Visible'),'on'); set(handles.radiobutton6,'Value',1); Pass{4}='y'; end
InterimDataCheck(hObject, eventdata, handles)

%%%%%%%%%%%%%%%%%%check lines 351-365
S=get(handles.pushbutton2,'String');
if S(1) == 'S' % Select All
set(handles.radiobutton3,'Value',1)
set(handles.radiobutton4,'Value',1) 
set(handles.radiobutton5,'Value',1)
set(handles.radiobutton6,'Value',1)
set(handles.pushbutton2,'String','Clear All')
elseif S(1) == 'C' % Clear All
set(handles.radiobutton3,'Value',0)
set(handles.radiobutton4,'Value',0) 
set(handles.radiobutton5,'Value',0)
set(handles.radiobutton6,'Value',0)
set(handles.pushbutton2,'String','Select All')
end 
%%%%%%%%%%%%%%%%%%%

function InterimDataCheck(hObject, eventdata, handles)
t0=get(handles.radiobutton1,'Value'); % Climatology
t1=get(handles.radiobutton3,'Value');
t2=get(handles.radiobutton4,'Value');
t3=get(handles.radiobutton5,'Value');
t4=get(handles.radiobutton6,'Value');
Year2=str2num(deblank(get(handles.edit4,'String')));
S='';
set(handles.radiobutton3,'ForegroundColor',[0. 0. 0.])
set(handles.radiobutton4,'ForegroundColor',[0. 0. 0.])
set(handles.radiobutton5,'ForegroundColor',[0. 0. 0.])
set(handles.radiobutton6,'ForegroundColor',[0. 0. 0.])
if Year2>=2004 & (t2==1 | t4==1) & t0==0 
S='From 2004-01-01 all data are interim products and will be replaced in the future';
set(handles.radiobutton4,'ForegroundColor',[1. 0. 0.])
set(handles.radiobutton6,'ForegroundColor',[1. 0. 0.])
end
if Year2>=2002 & (t1==1 | t3==1) & t0==0
S='From 2002-01-01 some data are interim products and will be replaced in the future';
set(handles.radiobutton3,'ForegroundColor',[1. 0. 0.])
set(handles.radiobutton5,'ForegroundColor',[1. 0. 0.])
end
set(handles.text18,'String',S)

function ClimTimeSeriesCheck(hObject, eventdata, handles)
if get(handles.radiobutton1,'Value') == 0 % Time Series
        
    set(handles.checkbox1,'Enable','Off')
    set(handles.checkbox2,'Enable','Off')
    set(handles.checkbox3,'Enable','Off')
    set(handles.checkbox4,'Enable','Off')
    
    set(handles.checkbox5,'Enable','On')
    set(handles.checkbox6,'Enable','On')
    set(handles.checkbox7,'Enable','On')
    set(handles.checkbox8,'Enable','On')
    set(handles.checkbox9,'Enable','On')
    set(handles.checkbox10,'Enable','On')
    set(handles.checkbox11,'Enable','On')
    set(handles.checkbox12,'Enable','On')
    set(handles.checkbox13,'Enable','On')
    set(handles.checkbox14,'Enable','On')
    
    if get(handles.checkbox8,'Value') == 1
    set(handles.popupmenu1,'BackgroundColor',[1. 1. 1.],'Enable','On')
    end
  
    set(handles.edit1,'Visible','On','Enable','On')
    set(handles.edit4,'Visible','On','Enable','On')
    set(handles.text12,'Visible','On')
    set(handles.text15,'Visible','On')
    set(handles.text10,'Visible','On')
    set(handles.popupmenu3,'Visible','Off','Enable','Off')
    set(handles.popupmenu2,'Visible','On','Enable','On')
    
    set(handles.radiobutton4,'Visible','On','Enable','On')
    set(handles.radiobutton6,'Visible','On','Enable','On')

else % Climatology
    set(handles.checkbox1,'Enable','On')
    set(handles.checkbox2,'Enable','On')
    set(handles.checkbox3,'Enable','On')
    set(handles.checkbox4,'Enable','On')
        
    set(handles.checkbox5,'Enable','Off')
    set(handles.checkbox6,'Enable','Off')
    set(handles.checkbox7,'Enable','Off')
    set(handles.checkbox8,'Enable','Off')
    set(handles.checkbox9,'Enable','Off')
    set(handles.checkbox10,'Enable','Off')
    set(handles.checkbox11,'Enable','Off')
    set(handles.checkbox12,'Enable','Off')
    set(handles.checkbox13,'Enable','Off')
    set(handles.checkbox14,'Enable','Off')
    
    set(handles.popupmenu1,'BackgroundColor',[0.878 0.875 0.891],'Enable','Off')
    
    set(handles.edit1,'Visible','Off','Enable','Off')
    set(handles.edit4,'Visible','Off','Enable','Off')
    set(handles.text12,'Visible','Off')
    set(handles.text15,'Visible','Off')
    set(handles.text10,'Visible','Off')
    
    set(handles.popupmenu3,'Visible','On','Enable','On')
    set(handles.popupmenu2,'Visible','Off','Enable','Off')
    
    set(handles.radiobutton4,'Value',0,'Visible','Off','Enable','Off')
    set(handles.radiobutton6,'Value',0,'Visible','Off','Enable','Off')
end
if get(handles.radiobutton1,'Value')==1
S=get(handles.popupmenu3,'String');j=get(handles.popupmenu3,'Value');S=deblank(S{j});
set(handles.text42,'Visible','Off')
set(handles.text43,'String','1985-2001')
else 
S=get(handles.popupmenu2,'String');j=get(handles.popupmenu2,'Value');S=deblank(S{j});
set(handles.text42,'Visible','On')
set(handles.text43,'String','1985-2002')
end
TXT=['Temporal resolution is ' lower(S)];
set(handles.text45,'String',TXT,'ForegroundColor',[0 0 1])

function radiobutton7_Callback(hObject, eventdata, handles)
function radiobutton8_Callback(hObject, eventdata, handles)
SaveFilesOnOff(hObject, eventdata, handles)

function popupmenu4_Callback(hObject, eventdata, handles)
function popupmenu4_CreateFcn(hObject, eventdata, handles)

function pushbutton3_Callback(hObject, eventdata, handles)
if get(handles.radiobutton8,'Value') == 1
DIRNAME=uigetdir(pwd,'Select a Directory for Downloading Files');
set(handles.edit14,'String',DIRNAME)
end

% The main button that starts data acquisition
function pushbutton4_Callback(hObject, eventdata, handles)
% set(handles.pushbutton4,'String','For a new request reissue Get_Pathfinder')
% uiresume(handles.figure1)
%% Turn off ability to re-issue "Get Data."
set(hObject,'BackgroundColor',[0.878 0.875 0.891],'Enable','Off','String','Please wait...');
pause(.1)

% Get input from GUI
request=InputGet(hObject, eventdata, handles);

%% Remember request.
pname = strrep(mfilename('fullpath'),mfilename,'');
fname = [mfilename,'_request','.mat'];
save([pname,fname],'request','-mat')

%'gui_pathfinder4km_request.mat';
if exist([pname,fname],'file') 
    set (handles.pushbutton6,'Enable','On')
end

% If it passes inspection, send down to user's workspace
% as variable "request". Then the user can get the data
assignin('base','request',request);

get_pathfinder4km(request);

set(hObject,'Enable','On','String','Get Data','BackgroundColor',[0 1. 0.25])

function pushbutton5_Callback(hObject, eventdata, handles)
web 'http://www.nodc.noaa.gov/sog/pathfinder4km/userguide.html' -browser
function pushbutton7_Callback(hObject, eventdata, handles)
web 'http://www.opendap.org/' -browser
function pushbutton8_Callback(hObject, eventdata, handles)
web 'http://dods.jpl.nasa.gov/' -browser
function pushbutton9_Callback(hObject, eventdata, handles)
web 'http://www.nasa.gov' -browser

function pushbutton10_Callback(hObject, eventdata, handles)
h = op_timemessage('polar',0);

function request=InputGet(hObject, eventdata, handles)

S1=deblank(get(handles.edit1,'String'));
S2=deblank(get(handles.edit2,'String'));
%if length(S2) == 1 S2=['0' S2]; end
S3=deblank(get(handles.edit3,'String'));
%if length(S3) == 1 S3=['0' S3]; end
S4=deblank(get(handles.edit4,'String'));
S5=deblank(get(handles.edit5,'String'));
%if length(S5) == 1 S5=['0' S5]; end
S6=deblank(get(handles.edit6,'String'));
%if length(S6) == 1 S6=['0' S6]; end

R.DATE1='00000000';
R.DATE1(4-length(S1)+1:4)=S1;
R.DATE1(6-length(S2)+1:6)=S2;
R.DATE1(8-length(S3)+1:8)=S3;
R.DATE2='00000000';
R.DATE2(4-length(S4)+1:4)=S4;
R.DATE2(6-length(S5)+1:6)=S5;
R.DATE2(8-length(S6)+1:8)=S6;

%DATE1=[S1 S2 S3];
%DATE2=[S4 S5 S6];
%DATEINCR=1;
R.DATEINCR=str2num(deblank(get(handles.edit11,'String')));

R.LAT1=str2num(deblank(get(handles.edit7,'String')));
R.LAT2=str2num(deblank(get(handles.edit8,'String')));
R.LON1=str2num(deblank(get(handles.edit9,'String')));
R.LON2=str2num(deblank(get(handles.edit10,'String')));
R.LATINCR=str2num(deblank(get(handles.edit12,'String')));
R.LONINCR=str2num(deblank(get(handles.edit13,'String')));

R.DIRNAME =deblank(get(handles.edit14,'String'));
if isempty(R.DIRNAME) R.DIRNAME=''; end
R.FNPREFIX=deblank(get(handles.edit15,'String'));

R.Clim_Fields={'Clim_SST','n';'Clim_StandardDeviation','n';'Clim_Counts','n'};
R.Fields={'sst','n';'bsst','n';'sdev','n';'mask1','n';'mask2','n';'num','n';'qual','n'};

if get(handles.checkbox1,'Value')==1 R.Clim_Fields{1,2}='y'; end
if get(handles.checkbox3,'Value')==1 R.Clim_Fields{2,2}='y'; end
if get(handles.checkbox4,'Value')==1 R.Clim_Fields{3,2}='y'; end

if get(handles.checkbox5 ,'Value')==1 R.Fields{1,2}='y'; end
if get(handles.checkbox9 ,'Value')==1 R.Fields{7,2}='y'; end
if get(handles.checkbox10,'Value')==1 R.Fields{2,2}='y'; end
if get(handles.checkbox11 ,'Value')==1 R.Fields{3,2}='y'; end
if get(handles.checkbox12,'Value')==1 R.Fields{4,2}='y'; end
if get(handles.checkbox13,'Value')==1 R.Fields{6,2}='y'; end
if get(handles.checkbox14,'Value')==1 R.Fields{5,2}='y'; end

R.ApplyLandMask='n';
if get(handles.checkbox2 ,'Value')==1 R.ApplyLandMask='y'; end
if get(handles.checkbox6 ,'Value')==1 R.ApplyLandMask='y'; end

R.ApplyQualMask='n';
if get(handles.checkbox8 ,'Value')==1 
S=get(handles.popupmenu1,'String');j=get(handles.popupmenu1,'Value');
R.ApplyQualMask=S{j}(3); %'n','4','7'
end

R.CalcAnomaly='n';
if get(handles.checkbox7 ,'Value')==1 R.CalcAnomaly='y'; end

S=get(handles.popupmenu3,'String');j=get(handles.popupmenu3,'Value');
R.Climatology=deblank(S{j});

S=get(handles.popupmenu2,'String');j=get(handles.popupmenu2,'Value');
R.TimeSeries=deblank(S{j});
if get(handles.radiobutton1,'Value')==0 R.Climatology=''; end
if get(handles.radiobutton2,'Value')==0 R.TimeSeries=''; end

if ~isempty(R.Climatology)
    R.DATE1(1:4)='0000';R.DATE2(1:4)='0000';
    % if climatology request spans a new year, as in Dec-Jan period
    if str2num(R.DATE2)<str2num(R.DATE1) R.DATE2(1:4)='0001'; end 
end      

R.Pass={'n';'n';'n';'n'}; 
if get(handles.radiobutton3,'Value') == 1 R.Pass{1}='y'; end
if get(handles.radiobutton4,'Value') == 1 R.Pass{2}='y'; end
if get(handles.radiobutton5,'Value') == 1 R.Pass{3}='y'; end
if get(handles.radiobutton6,'Value') == 1 R.Pass{4}='y'; end
    
R.SaveWorkspace='n'; 
if get(handles.radiobutton7,'Value') == 1 R.SaveWorkspace='y'; end
R.SaveFiles='n'; 
if get(handles.radiobutton8,'Value') == 1 R.SaveFiles='y'; end

S=get(handles.popupmenu4,'String');j=get(handles.popupmenu4,'Value');
R.SaveMode=deblank(S{j});

%% Get default command line output from handles structure.   
R.RequestDate=datestr(now,'yyyy-mm-dd HH:MM:SS');
request=R;
handles.request=request;

% Load Last request
function pushbutton6_Callback(hObject, eventdata, handles)

pname = strrep(mfilename('fullpath'),mfilename,'');
fname = [mfilename,'_request','.mat'];
if exist([pname,fname],'file')
load([pname,fname]);
else
msgbox(['File ',[pname,fname],' does not exist.']);
return
end

R=request;

set(handles.edit1,'String',R.DATE1(1:4));
set(handles.edit2,'String',R.DATE1(5:6)); 
set(handles.edit3,'String',R.DATE1(7:8)); 
set(handles.edit4,'String',R.DATE2(1:4));
set(handles.edit5,'String',R.DATE2(5:6)); 
set(handles.edit6,'String',R.DATE2(7:8)); 
set(handles.edit7,'String',num2str(R.LAT1));
set(handles.edit8,'String',num2str(R.LAT2));
set(handles.edit9,'String',num2str(R.LON1));
set(handles.edit10,'String',num2str(R.LON2));
set(handles.edit11,'String',num2str(R.DATEINCR));
set(handles.edit12,'String',num2str(R.LATINCR));
set(handles.edit13,'String',num2str(R.LONINCR));
set(handles.edit14,'String',R.DIRNAME);
set(handles.edit15,'String',R.FNPREFIX);

if isempty(R.Climatology)
    set(handles.radiobutton1,'Value',0)
    set(handles.radiobutton2,'Value',1)
else
    set(handles.radiobutton1,'Value',1)
    set(handles.radiobutton2,'Value',0)
end

set(handles.checkbox1,'Value',0); 
set(handles.checkbox3,'Value',0); 
set(handles.checkbox4,'Value',0); 
if R.Clim_Fields{1,2}=='y' set(handles.checkbox1,'Value',1); end
if R.Clim_Fields{2,2}=='y' set(handles.checkbox3,'Value',1); end
if R.Clim_Fields{3,2}=='y' set(handles.checkbox4,'Value',1); end

set(handles.checkbox5 ,'Value',0); 
set(handles.checkbox9 ,'Value',0); 
set(handles.checkbox10,'Value',0); 
set(handles.checkbox11 ,'Value',0);
set(handles.checkbox12,'Value',0); 
set(handles.checkbox13,'Value',0); 
set(handles.checkbox14,'Value',0); 
if R.Fields{1,2}=='y' set(handles.checkbox5 ,'Value',1); end
if R.Fields{7,2}=='y' set(handles.checkbox9 ,'Value',1); end
if R.Fields{2,2}=='y' set(handles.checkbox10,'Value',1); end
if R.Fields{3,2}=='y' set(handles.checkbox11 ,'Value',1); end
if R.Fields{4,2}=='y' set(handles.checkbox12,'Value',1); end
if R.Fields{6,2}=='y' set(handles.checkbox13,'Value',1); end
if R.Fields{5,2}=='y' set(handles.checkbox14,'Value',1); end

set(handles.checkbox2 ,'Value',0);
set(handles.checkbox6 ,'Value',0);
if R.ApplyLandMask=='y' & get(handles.radiobutton1,'Value')==1 set(handles.checkbox2 ,'Value',1); end
if R.ApplyLandMask=='y' & get(handles.radiobutton2,'Value')==1 set(handles.checkbox6 ,'Value',1); end

%ApplyQualMask=S{j}(3); %'n','4','7'
R.ApplyQualMask;
S=get(handles.popupmenu1,'String');
S=strvcat(S);
j=strfind(S(:,3)',R.ApplyQualMask);
if ~isempty(j) 
    set(handles.checkbox8 ,'Value',1); 
    set(handles.popupmenu1,'Value',j);
else
    set(handles.checkbox8 ,'Value',0);
end

set(handles.checkbox7 ,'Value',0);
if R.CalcAnomaly=='y' set(handles.checkbox7 ,'Value',1); end

S=get(handles.popupmenu3,'String');
j=find(strcmp(S,R.Climatology));
if isempty(j) j=1; end
set(handles.popupmenu3,'Value',j);
S=get(handles.popupmenu2,'String');
j=find(strcmp(S,R.TimeSeries));
if isempty(j) j=1; end
set(handles.popupmenu2,'Value',j);

ClimTimeSeriesCheck(hObject, eventdata, handles)

set(handles.radiobutton3,'Value',0);
set(handles.radiobutton4,'Value',0);
set(handles.radiobutton5,'Value',0);
set(handles.radiobutton6,'Value',0);
if R.Pass{1}=='y' set(handles.radiobutton3,'Value',1); end
if R.Pass{2}=='y' set(handles.radiobutton4,'Value',1); end
if R.Pass{3}=='y' set(handles.radiobutton5,'Value',1); end
if R.Pass{4}=='y' set(handles.radiobutton6,'Value',1); end

set(handles.radiobutton7,'Value',0);
set(handles.radiobutton8,'Value',0);
if R.SaveWorkspace=='y' set(handles.radiobutton7,'Value',1); end
if R.SaveFiles=='y' set(handles.radiobutton8,'Value',1); end

S=get(handles.popupmenu4,'String');
j=find(strcmp(S,R.SaveMode));
if isempty(j) j=1; end
set(handles.popupmenu4,'Value',j);

ClimTimeSeriesCheck(hObject, eventdata, handles)
QualMaskOnOff(hObject, eventdata, handles)
InterimDataCheck(hObject, eventdata, handles)
SaveFilesOnOff(hObject, eventdata, handles)

function SaveFilesOnOff(hObject, eventdata, handles)   
% Set color of data documentation button to match figure color.
%BGColor = get(hObject,'Color'); %here hObject is the current figure
BGColor=[0.878 0.875 0.891];
if get(handles.radiobutton8,'Value') == 0
    set(handles.edit14,'BackgroundColor',BGColor,'Enable','Off')
    set(handles.edit15,'BackgroundColor',BGColor,'Enable','Off')
elseif get(handles.radiobutton8,'Value') == 1
    set(handles.edit14,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.edit15,'BackgroundColor',[1. 1. 1.],'Enable','On')
end

function QualMaskOnOff(hObject, eventdata, handles)
% Set color of data documentation button to match figure color.
%BGColor = get(hObject,'Color'); %here hObject is the current figure
BGColor=[0.878 0.875 0.891];
if     get(handles.checkbox8,'Value') == 0
   set(handles.popupmenu1,'BackgroundColor',BGColor,'Enable','Off')
elseif get(handles.checkbox8,'Value') == 1
   set(handles.popupmenu1,'BackgroundColor',[1.0 1.0 1.0],'Enable','On')
end

S='';
if get(handles.checkbox2,'Value') == 1 
S='A new variable Clim_SST_masked will be created'; end
set(handles.text5,'String',S)

S='';
if get(handles.checkbox8,'Value') == 1 | get(handles.checkbox6,'Value') == 1
S='A new variable sst_masked and/or ssta_masked will be created'; end
set(handles.text8,'String',S)

% Update File list
function pushbutton1_Callback(hObject, eventdata, handles)
tmp = mfilename;
tmp = strrep(lower(tmp),'get','gui');
tmp = strrep(tmp,'.m','');
tmp = strcat(tmp,'_filelist','.mat');
ButtonName=questdlg(['You requested to update the list of files ',...
    'in the Pathfinder4km archive and overwrite ',...
    tmp,'. This may take up to 2 hours.'], ...
    'Pathfinder4km Update File List','Continue','Cancel','Cancel');
if strcmp(ButtonName,'Cancel') return; end
get_pathfinder4km_filelist

function get_pathfinder4km_filelist_old
% script to get the list of files in the Pathfinder time series archive
clear all

URLBase2='http://data.nodc.noaa.gov/cgi-bin/nph-dods/pathfinder/Version5.0'
%URLBase2=['http://dods.jpl.nasa.gov/dods-bin/nph-hdf/pub/',...
%    'sea_surface_temperature/avhrr/pathfinder/data_v5'];
URLBase='http://data.nodc.noaa.gov/pathfinder/Version5.0'

% dum = [1985:2005];
% URLYear=num2str(dum');
URLYear=['1985';'1986';'1987';'1988';'1989';...
'1990';'1991';'1992';'1993';'1994';'1995';'1996';'1997';'1998';'1999';...
'2000';'2001';'2002';'2003';'2004';'2005']

a=[1985:str2num(datestr(now,'yyyy'))]
URLYear=num2str(a(:))
URLTempAvg={'Yearly';'Monthly';'8day';'7day';'5day';'Daily'}

% maximum number of characters from the beginning of a file 
% to string '-sst-16b.hdf'
idash=28; 
[NTA,N2]=size(URLTempAvg);
for kTA=1:NTA
TempAvg=URLTempAvg{kTA,:}

[NY,N2]=size(URLYear);
DataSetFiles={};

% Progress bar
hwaitbar=waitbar(0,'Acquiring list of files','Name','Pathfinder4km Download Progress');
for k=1:NY

Year=URLYear(k,:);
xprogr=((k-1)/NY); % progress fraction
waitbar( xprogr , hwaitbar, ['Acquiring list of files: ' Year ' ' TempAvg],'Name','Pathfinder4km Download Progress');

for kV=1:4
    
if      kV==1 VERSION=''; 
elseif  kV==2 VERSION='_interim_NOAA16'; 
elseif  kV==3 VERSION='_NOAA17'; 
elseif  kV==4 VERSION='_interim_NOAA17'; 
end    
URL=[URLBase VERSION '/' TempAvg '/' Year]
[DirList,URLReadStatus]=urlread(URL);

    if URLReadStatus==1
    nn = findstr(DirList,'-sst-16b.hdf"')'
        for i=1:length(nn)
    fn=DirList(nn(i)-idash:nn(i)+11);
    nnn=max(findstr(fn,'"'));
    fn=fn(nnn+1:end);
    DataSetFiles = [DataSetFiles; {fn}];
        end
% some files have ending '-16b.hdf'
    nn = findstr(DirList,'-sst.hdf"')';
        for i=1:length(nn)
    fn=DirList(nn(i)-idash:nn(i)+7);
    nnn=max(findstr(fn,'"'));
    fn=fn(nnn+1:end);
    DataSetFiles = [DataSetFiles; {fn}];
        end
    end

end % kV

end % k URLYears
close(hwaitbar)

eval(['PFList' TempAvg '=DataSetFiles;'])

end % kTA

loaddap([URLBase2 '/Daily/1985/1985004.s04d1pfv50-sst-16b.hdf?lat,lon']) 
Latitude=sst.lat;
Longitude=sst.lon;
%load Latitude
%load Longitude

% theoretical values 
d=180/4096;
Latitude1=(90-d/2:-d:-90+d/2)';
Longitude1=(-180+d/2:d:180-d/2)';

% ?????
% there is a slight difference between Latitude and Latitude1, order of (0.1*d)
% there is a slight difference between Longitude and Longitude1, order of (0.1*d)
%figure;plot(Latitude-Latitude1)
%figure;plot(Longitude-Longitude1)

%tmp = mfilename;
%tmp = strrep(lower(tmp),'get','gui');
%tmp = strrep(tmp,'.m','');
save gui_pathfinder4km_filelist.mat Latitude Longitude ...
    PFListDaily ... 
    PFList5day ... 
    PFList7day ... 
    PFList8day ... 
    PFListMonthly ... 
    PFListYearly
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function get_pathfinder4km_filelist
% script to get the list of files in the Pathfinder time series archive
clear all

%URLBase2='http://data.nodc.noaa.gov/cgi-bin/nph-dods/pathfinder/Version5.0'
%URLBase2=['http://dods.jpl.nasa.gov/dods-bin/nph-hdf/pub/',...
%    'sea_surface_temperature/avhrr/pathfinder/data_v5'];
%URLBase='http://data.nodc.noaa.gov/pathfinder/Version5.0'

% Example of an individual data file URL:
%'http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder
%/data_v5/daily/ascending/04km/2005/sst/2005001.s04d4pfrt-sst.hdf
%?sst[0:1:4095][0:1:8191]'
URLBase='http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder/data_v5';

URLTempAvgFN={'Yearly';'Monthly';'8day';'7day';'5day';'Daily'}
URLTempAvg={'yearly';'monthly';'8day';'7day';'5day';'daily'} % directory name in the latest dataset
% testing
%URLTempAvgFN={'Monthly'}
%URLTempAvg={'monthly'} % directory name in the latest dataset
URLPass={'ascending';'descending'};

% URLYear=num2str([1985:2005]');
%URLYear=['1985';'1986';'1987';'1988';'1989';...
%'1990';'1991';'1992';'1993';'1994';'1995';'1996';'1997';'1998';'1999';...
%'2000';'2001';'2002';'2003';'2004';'2005']
a=[1985:str2num(datestr(now,'yyyy'))]
URLYear=num2str(a(:))

% maximum number of characters from the beginning of a file 
% to string '-sst-16b.hdf'
idash=28; 
[NTA,N2]=size(URLTempAvg);
for kTA=1:NTA
TempAvg=URLTempAvg{kTA,:}
TempAvgFN=URLTempAvgFN{kTA,:};

[NY,N2]=size(URLYear);
DataSetFiles={};

% Progress bar
hwaitbar=waitbar(0,'Acquiring list of files','Name','Pathfinder4km Download Progress');
    for kPass=1:2
    Pass=URLPass{kPass,:}

        for k=1:NY

Year=URLYear(k,:);
xprogr=((k-1)/NY); % progress fraction
waitbar( xprogr , hwaitbar, ['Acquiring list of files: ' Year ' ' Pass ' ' TempAvg],'Name','Pathfinder4km Download Progress');

 %'http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder/data_v5/'
%'http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder/data_v5/
%daily/ascending/04km/2005/sst/2005001.s04d4pfrt-sst.hdf
%?sst[0:1:4095][0:1:8191]'
   
URL=[URLBase '/' TempAvg '/' Pass '/04km/' Year '/sst']
[DirList,URLReadStatus]=urlread(URL)

            if URLReadStatus==1
    nn = findstr(DirList,'-sst-16b.hdf</a>')';
                for i=1:length(nn)
    fn=DirList(nn(i)-idash:nn(i)+11);
    nnn=max(findstr(fn,'>'));
    fn=fn(nnn+1:end);
    DataSetFiles = [DataSetFiles; {fn}];
                end
% some files have ending '-16b.hdf'
    nn = findstr(DirList,'-sst.hdf</a>')';
                for i=1:length(nn)
    fn=DirList(nn(i)-idash:nn(i)+7);
    nnn=max(findstr(fn,'>'));
    fn=fn(nnn+1:end);
    DataSetFiles = [DataSetFiles; {fn}];
                end
            end

        end % k URLYears
    end % kPass
close(hwaitbar)
NFiles=length(DataSetFiles)
eval(['PFList' TempAvgFN '=DataSetFiles;'])

end % kTA

%loaddap([URLBase2 '/Daily/1985/1985004.s04d1pfv50-sst-16b.hdf?lat,lon']) 
%Latitude=sst.lat;
%Longitude=sst.lon;
%load Latitude
%load Longitude

% theoretical values 
d=180/4096;
Latitude=(90-d/2:-d:-90+d/2)';
Longitude=(-180+d/2:d:180-d/2)';

% ?????
% there is a slight difference between Latitude and Latitude1, order of (0.1*d)
% there is a slight difference between Longitude and Longitude1, order of (0.1*d)
%figure;plot(Latitude-Latitude1)
%figure;plot(Longitude-Longitude1)

%tmp = mfilename;
%tmp = strrep(lower(tmp),'get','gui');
%tmp = strrep(tmp,'.m','');
%tmp = 'gui_pathfinder4km';
%load(strcat(tmp,'_filelist','.mat'),'Latitude','Longitude', ...
%    'PFListDaily', ... 
%    'PFList5day', ... 
%    'PFList7day', ... 
%    'PFList8day', ... 
%    'PFListMonthly', ... 
%    'PFListYearly');

save gui_pathfinder4km_filelist.mat Latitude Longitude ...
    PFListDaily ... 
    PFList5day ... 
    PFList7day ... 
    PFList8day ... 
    PFListMonthly ... 
    PFListYearly

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

